@@ -31,6 +31,7 @@ from google.api_core import page_iterator
 from google.cloud._helpers import _LocalStack, _NOW
 from google.cloud.client import ClientWithProject
 from google.cloud.exceptions import NotFound
+from google.cloud.storage._helpers import _get_environ_project
 from google.cloud.storage._helpers import _get_storage_host
 from google.cloud.storage._helpers import _DEFAULT_STORAGE_HOST
 from google.cloud.storage._helpers import _bucket_bound_hostname_url
@@ -121,13 +122,6 @@ class Client(ClientWithProject):
         if project is _marker:
             project = None
 
-        super(Client, self).__init__(
-            project=project,
-            credentials=credentials,
-            client_options=client_options,
-            _http=_http,
-        )
-
         kw_args = {"client_info": client_info}
 
         # `api_endpoint` should be only set by the user via `client_options`,
@@ -148,6 +142,27 @@ class Client(ClientWithProject):
                 api_endpoint = client_options.api_endpoint
                 kw_args["api_endpoint"] = api_endpoint
 
+        # Use anonymous credentials and no project when
+        # STORAGE_EMULATOR_HOST or a non-default api_endpoint is set.
+        if (
+            kw_args["api_endpoint"] is not None
+            and kw_args["api_endpoint"].find("storage.googleapis.com") < 0
+        ):
+            if credentials is None:
+                credentials = AnonymousCredentials()
+            if project is None:
+                project = _get_environ_project()
+            if project is None:
+                no_project = True
+                project = "<none>"
+
+        super(Client, self).__init__(
+            project=project,
+            credentials=credentials,
+            client_options=client_options,
+            _http=_http,
+        )
+
         if no_project:
             self.project = None
 
@@ -1065,7 +1080,7 @@ class Client(ClientWithProject):
             >>> bucket = client.get_bucket('my-bucket-name')
             >>> blob = storage.Blob('path/to/blob', bucket)
 
-            >>> with open('file-to-download-to') as file_obj:
+            >>> with open('file-to-download-to', 'w') as file_obj:
             >>>     client.download_blob_to_file(blob, file_obj)  # API request.
 
 
@@ -1074,7 +1089,7 @@ class Client(ClientWithProject):
             >>> from google.cloud import storage
             >>> client = storage.Client()
 
-            >>> with open('file-to-download-to') as file_obj:
+            >>> with open('file-to-download-to', 'w') as file_obj:
             >>>     client.download_blob_to_file(
             >>>         'gs://bucket_name/path/to/blob', file_obj)
 
